"use strict";
/**
 * (C) Copyright IBM Corp. 2021.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * IBM OpenAPI SDK Code Generator Version: 3.29.1-b338fb38-20210313-010605
 */
var extend = require("extend");
var ibm_cloud_sdk_core_1 = require("ibm-cloud-sdk-core");
var common_1 = require("../lib/common");
/**
 * Management interface for IBM Cloud Container Registry
 */
var ContainerRegistryV1 = /** @class */ (function (_super) {
    __extends(ContainerRegistryV1, _super);
    /**
     * Construct a ContainerRegistryV1 object.
     *
     * @param {Object} options - Options for the service.
     * @param {string} options.account - The unique ID for your IBM Cloud account.
     * @param {string} [options.serviceUrl] - The base url to use when contacting the service. The base url may differ between IBM Cloud regions.
     * @param {OutgoingHttpHeaders} [options.headers] - Default headers that shall be included with every request to the service.
     * @param {Authenticator} options.authenticator - The Authenticator object used to authenticate requests to the service
     * @constructor
     * @returns {ContainerRegistryV1}
     */
    function ContainerRegistryV1(options) {
        var _this = this;
        options = options || {};
        var requiredParams = ['account'];
        var missingParams = ibm_cloud_sdk_core_1.getMissingParams(options, requiredParams);
        if (missingParams) {
            throw missingParams;
        }
        _this = _super.call(this, options) || this;
        if (options.serviceUrl) {
            _this.setServiceUrl(options.serviceUrl);
        }
        else {
            _this.setServiceUrl(ContainerRegistryV1.DEFAULT_SERVICE_URL);
        }
        _this.account = options.account;
        return _this;
    }
    /*************************
     * Factory method
     ************************/
    /**
     * Constructs an instance of ContainerRegistryV1 with passed in options and external configuration.
     *
     * @param {UserOptions} [options] - The parameters to send to the service.
     * @param {string} [options.serviceName] - The name of the service to configure
     * @param {Authenticator} [options.authenticator] - The Authenticator object used to authenticate requests to the service
     * @param {string} [options.serviceUrl] - The URL for the service
     * @returns {ContainerRegistryV1}
     */
    ContainerRegistryV1.newInstance = function (options) {
        options = options || {};
        if (!options.serviceName) {
            options.serviceName = this.DEFAULT_SERVICE_NAME;
        }
        if (!options.authenticator) {
            options.authenticator = ibm_cloud_sdk_core_1.getAuthenticatorFromEnvironment(options.serviceName);
        }
        var service = new ContainerRegistryV1(options);
        service.configureService(options.serviceName);
        if (options.serviceUrl) {
            service.setServiceUrl(options.serviceUrl);
        }
        return service;
    };
    /*************************
     * authorization
     ************************/
    /**
     * Get authorization options.
     *
     * Get authorization options for the targeted account.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.AuthOptions>>}
     */
    ContainerRegistryV1.prototype.getAuth = function (params) {
        var _params = Object.assign({}, params);
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'getAuth');
        var parameters = {
            options: {
                url: '/api/v1/auth',
                method: 'GET',
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /**
     * Update authorization options.
     *
     * Update authorization options for the targeted account.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {boolean} [params.iamAuthz] - Enable role based authorization when authenticating with IBM Cloud IAM.
     * @param {boolean} [params.privateOnly] - Restrict account to only be able to push and pull images over private
     * connections.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.Empty>>}
     */
    ContainerRegistryV1.prototype.updateAuth = function (params) {
        var _params = Object.assign({}, params);
        var body = {
            'iam_authz': _params.iamAuthz,
            'private_only': _params.privateOnly
        };
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'updateAuth');
        var parameters = {
            options: {
                url: '/api/v1/auth',
                method: 'PATCH',
                body: body,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Content-Type': 'application/json',
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /*************************
     * images
     ************************/
    /**
     * List images.
     *
     * List all images in namespaces in a targeted IBM Cloud account.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {string} [params.namespace] - Lists images that are stored in the specified namespace only. Query multiple
     * namespaces by specifying this option for each namespace. If this option is not specified, images from all
     * namespaces in the specified IBM Cloud account are listed.
     * @param {boolean} [params.includeIbm] - Includes IBM-provided public images in the list of images. If this option is
     * not specified, private images are listed only. If this option is specified more than once, the last parsed setting
     * is the setting that is used.
     * @param {boolean} [params.includePrivate] - Includes private images in the list of images. If this option is not
     * specified, private images are listed. If this option is specified more than once, the last parsed setting is the
     * setting that is used.
     * @param {boolean} [params.includeManifestLists] - Includes tags that reference multi-architecture manifest lists in
     * the image list. If this option is not specified, tagged manifest lists are not shown in the list. If this option is
     * specified more than once, the last parsed setting is the setting that is used.
     * @param {boolean} [params.vulnerabilities] - Displays Vulnerability Advisor status for the listed images. If this
     * option is specified more than once, the last parsed setting is the setting that is used.
     * @param {string} [params.repository] - Lists images that are stored in the specified repository, under your
     * namespaces. Query multiple repositories by specifying this option for each repository. If this option is not
     * specified, images from all repos are listed.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.RemoteAPIImage[]>>}
     */
    ContainerRegistryV1.prototype.listImages = function (params) {
        var _params = Object.assign({}, params);
        var query = {
            'namespace': _params.namespace,
            'includeIBM': _params.includeIbm,
            'includePrivate': _params.includePrivate,
            'includeManifestLists': _params.includeManifestLists,
            'vulnerabilities': _params.vulnerabilities,
            'repository': _params.repository
        };
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'listImages');
        var parameters = {
            options: {
                url: '/api/v1/images',
                method: 'GET',
                qs: query,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /**
     * Bulk delete images.
     *
     * Remove multiple container images from the registry.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string[]} params.bulkDelete - The full IBM Cloud registry path to the images that you want to delete,
     * including its digest. All tags for the supplied digest are removed.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.ImageBulkDeleteResult>>}
     */
    ContainerRegistryV1.prototype.bulkDeleteImages = function (params) {
        var _params = Object.assign({}, params);
        var requiredParams = ['bulkDelete'];
        var missingParams = ibm_cloud_sdk_core_1.getMissingParams(_params, requiredParams);
        if (missingParams) {
            return Promise.reject(missingParams);
        }
        var body = _params.bulkDelete;
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'bulkDeleteImages');
        var parameters = {
            options: {
                url: '/api/v1/images/bulkdelete',
                method: 'POST',
                body: body,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Content-Type': 'application/json',
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /**
     * List images by digest.
     *
     * List all images by digest in namespaces in a targeted IBM Cloud account.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {boolean} [params.excludeTagged] - ExcludeTagged returns only untagged digests.
     * @param {boolean} [params.excludeVa] - ExcludeVA returns the digest list with no VA scan results.
     * @param {boolean} [params.includeIbm] - When true, API will return the IBM public images if they exist in the
     * targeted region.
     * @param {string[]} [params.repositories] - Repositories in which to restrict the output. If left empty all images
     * for the account will be returned.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.ImageDigest[]>>}
     */
    ContainerRegistryV1.prototype.listImageDigests = function (params) {
        var _params = Object.assign({}, params);
        var body = {
            'exclude_tagged': _params.excludeTagged,
            'exclude_va': _params.excludeVa,
            'include_ibm': _params.includeIbm,
            'repositories': _params.repositories
        };
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'listImageDigests');
        var parameters = {
            options: {
                url: '/api/v1/images/digests',
                method: 'POST',
                body: body,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Content-Type': 'application/json',
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /**
     * Create tag.
     *
     * Create a new tag in a private registry that refers to an existing image in the same region.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.fromimage - The name of the image that you want to create a new tag for, in the format
     * &lt;REPOSITORY&gt;:&lt;TAG&gt;. Run `ibmcloud cr images` or call the `GET /images/json` endpoint to review images
     * that are in the registry.
     * @param {string} params.toimage - The new tag for the image, in the format &lt;REPOSITORY&gt;:&lt;TAG&gt;.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.Empty>>}
     */
    ContainerRegistryV1.prototype.tagImage = function (params) {
        var _params = Object.assign({}, params);
        var requiredParams = ['fromimage', 'toimage'];
        var missingParams = ibm_cloud_sdk_core_1.getMissingParams(_params, requiredParams);
        if (missingParams) {
            return Promise.reject(missingParams);
        }
        var query = {
            'fromimage': _params.fromimage,
            'toimage': _params.toimage
        };
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'tagImage');
        var parameters = {
            options: {
                url: '/api/v1/images/tags',
                method: 'POST',
                qs: query,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /**
     * Delete image.
     *
     * Delete a container image from the registry.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.image - The full IBM Cloud registry path to the image that you want to delete, including its
     * tag. If you do not provide a specific tag, the version with the `latest` tag is removed.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.ImageDeleteResult>>}
     */
    ContainerRegistryV1.prototype.deleteImage = function (params) {
        var _params = Object.assign({}, params);
        var requiredParams = ['image'];
        var missingParams = ibm_cloud_sdk_core_1.getMissingParams(_params, requiredParams);
        if (missingParams) {
            return Promise.reject(missingParams);
        }
        var path = {
            'image': _params.image
        };
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'deleteImage');
        var parameters = {
            options: {
                url: '/api/v1/images/{image}',
                method: 'DELETE',
                path: path,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /**
     * Inspect an image.
     *
     * Inspect a container image in the private registry.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.image - The full IBM Cloud registry path to the image that you want to inspect. Run
     * `ibmcloud cr images` or call the `GET /images/json` endpoint to review images that are in the registry.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.ImageInspection>>}
     */
    ContainerRegistryV1.prototype.inspectImage = function (params) {
        var _params = Object.assign({}, params);
        var requiredParams = ['image'];
        var missingParams = ibm_cloud_sdk_core_1.getMissingParams(_params, requiredParams);
        if (missingParams) {
            return Promise.reject(missingParams);
        }
        var path = {
            'image': _params.image
        };
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'inspectImage');
        var parameters = {
            options: {
                url: '/api/v1/images/{image}/json',
                method: 'GET',
                path: path,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /**
     * Get image manifest.
     *
     * Get the manifest for a container image in the private registry.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.image - The full IBM Cloud registry path to the image that you want to inspect. Run
     * `ibmcloud cr images` or call the `GET /images/json` endpoint to review images that are in the registry.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.JsonObject>>}
     */
    ContainerRegistryV1.prototype.getImageManifest = function (params) {
        var _params = Object.assign({}, params);
        var requiredParams = ['image'];
        var missingParams = ibm_cloud_sdk_core_1.getMissingParams(_params, requiredParams);
        if (missingParams) {
            return Promise.reject(missingParams);
        }
        var path = {
            'image': _params.image
        };
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'getImageManifest');
        var parameters = {
            options: {
                url: '/api/v1/images/{image}/manifest',
                method: 'GET',
                path: path,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /*************************
     * messages
     ************************/
    /**
     * Get messages.
     *
     * Return any published system messages.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<string>>}
     */
    ContainerRegistryV1.prototype.getMessages = function (params) {
        var _params = Object.assign({}, params);
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'getMessages');
        var parameters = {
            options: {
                url: '/api/v1/messages',
                method: 'GET',
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /*************************
     * namespaces
     ************************/
    /**
     * List namespaces.
     *
     * List authorized namespaces in the targeted IBM Cloud account.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<string[]>>}
     */
    ContainerRegistryV1.prototype.listNamespaces = function (params) {
        var _params = Object.assign({}, params);
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'listNamespaces');
        var parameters = {
            options: {
                url: '/api/v1/namespaces',
                method: 'GET',
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /**
     * Detailed namespace list.
     *
     * Retrieves details, such as resource group, for all your namespaces in the targeted registry.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.NamespaceDetails[]>>}
     */
    ContainerRegistryV1.prototype.listNamespaceDetails = function (params) {
        var _params = Object.assign({}, params);
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'listNamespaceDetails');
        var parameters = {
            options: {
                url: '/api/v1/namespaces/details',
                method: 'GET',
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /**
     * Create namespace.
     *
     * Add a namespace to the targeted IBM Cloud account.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.name - The name of the namespace.
     * @param {string} [params.xAuthResourceGroup] - The ID of the resource group that the namespace will be created
     * within.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.Namespace>>}
     */
    ContainerRegistryV1.prototype.createNamespace = function (params) {
        var _params = Object.assign({}, params);
        var requiredParams = ['name'];
        var missingParams = ibm_cloud_sdk_core_1.getMissingParams(_params, requiredParams);
        if (missingParams) {
            return Promise.reject(missingParams);
        }
        var path = {
            'name': _params.name
        };
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'createNamespace');
        var parameters = {
            options: {
                url: '/api/v1/namespaces/{name}',
                method: 'PUT',
                path: path,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account,
                    'X-Auth-Resource-Group': _params.xAuthResourceGroup
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /**
     * Assign namespace.
     *
     * Assign a namespace to the specified resource group in the targeted IBM Cloud account.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.xAuthResourceGroup - The ID of the resource group that the namespace will be created within.
     * @param {string} params.name - The name of the namespace to be updated.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.Namespace>>}
     */
    ContainerRegistryV1.prototype.assignNamespace = function (params) {
        var _params = Object.assign({}, params);
        var requiredParams = ['xAuthResourceGroup', 'name'];
        var missingParams = ibm_cloud_sdk_core_1.getMissingParams(_params, requiredParams);
        if (missingParams) {
            return Promise.reject(missingParams);
        }
        var path = {
            'name': _params.name
        };
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'assignNamespace');
        var parameters = {
            options: {
                url: '/api/v1/namespaces/{name}',
                method: 'PATCH',
                path: path,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account,
                    'X-Auth-Resource-Group': _params.xAuthResourceGroup
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /**
     * Delete namespace.
     *
     * Delete the IBM Cloud Container Registry namespace from the targeted IBM Cloud account, and removes all images that
     * were in that namespace.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.name - The name of the namespace that you want to delete.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.Empty>>}
     */
    ContainerRegistryV1.prototype.deleteNamespace = function (params) {
        var _params = Object.assign({}, params);
        var requiredParams = ['name'];
        var missingParams = ibm_cloud_sdk_core_1.getMissingParams(_params, requiredParams);
        if (missingParams) {
            return Promise.reject(missingParams);
        }
        var path = {
            'name': _params.name
        };
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'deleteNamespace');
        var parameters = {
            options: {
                url: '/api/v1/namespaces/{name}',
                method: 'DELETE',
                path: path,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /*************************
     * plans
     ************************/
    /**
     * Get plans.
     *
     * Get plans for the targeted account.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.Plan>>}
     */
    ContainerRegistryV1.prototype.getPlans = function (params) {
        var _params = Object.assign({}, params);
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'getPlans');
        var parameters = {
            options: {
                url: '/api/v1/plans',
                method: 'GET',
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /**
     * Update plans.
     *
     * Update plans for the targeted account.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {string} [params.plan] -
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.Empty>>}
     */
    ContainerRegistryV1.prototype.updatePlans = function (params) {
        var _params = Object.assign({}, params);
        var body = {
            'plan': _params.plan
        };
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'updatePlans');
        var parameters = {
            options: {
                url: '/api/v1/plans',
                method: 'PATCH',
                body: body,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Content-Type': 'application/json',
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /*************************
     * quotas
     ************************/
    /**
     * Get quotas.
     *
     * Get quotas for the targeted account.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.Quota>>}
     */
    ContainerRegistryV1.prototype.getQuota = function (params) {
        var _params = Object.assign({}, params);
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'getQuota');
        var parameters = {
            options: {
                url: '/api/v1/quotas',
                method: 'GET',
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /**
     * Update quotas.
     *
     * Update quotas for the targeted account.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {number} [params.storageMegabytes] - Storage quota in megabytes. The value -1 denotes "Unlimited".
     * @param {number} [params.trafficMegabytes] - Traffic quota in megabytes. The value -1 denotes "Unlimited".
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.Empty>>}
     */
    ContainerRegistryV1.prototype.updateQuota = function (params) {
        var _params = Object.assign({}, params);
        var body = {
            'storage_megabytes': _params.storageMegabytes,
            'traffic_megabytes': _params.trafficMegabytes
        };
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'updateQuota');
        var parameters = {
            options: {
                url: '/api/v1/quotas',
                method: 'PATCH',
                body: body,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Content-Type': 'application/json',
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /*************************
     * retentions
     ************************/
    /**
     * List retention policies.
     *
     * List retention policies for all namespaces in the targeted IBM Cloud account.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.JsonObject>>}
     */
    ContainerRegistryV1.prototype.listRetentionPolicies = function (params) {
        var _params = Object.assign({}, params);
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'listRetentionPolicies');
        var parameters = {
            options: {
                url: '/api/v1/retentions',
                method: 'GET',
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /**
     * Set retention policy.
     *
     * Set the retention policy for the specified namespace.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.namespace - The namespace to which the retention policy is attached.
     * @param {number} [params.imagesPerRepo] - Determines how many images will be retained for each repository when the
     * retention policy is executed. The value -1 denotes 'Unlimited' (all images are retained).
     * @param {boolean} [params.retainUntagged] - Determines if untagged images are retained when executing the retention
     * policy. This is false by default meaning untagged images will be deleted when the policy is executed.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.Empty>>}
     */
    ContainerRegistryV1.prototype.setRetentionPolicy = function (params) {
        var _params = Object.assign({}, params);
        var requiredParams = ['namespace'];
        var missingParams = ibm_cloud_sdk_core_1.getMissingParams(_params, requiredParams);
        if (missingParams) {
            return Promise.reject(missingParams);
        }
        var body = {
            'namespace': _params.namespace,
            'images_per_repo': _params.imagesPerRepo,
            'retain_untagged': _params.retainUntagged
        };
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'setRetentionPolicy');
        var parameters = {
            options: {
                url: '/api/v1/retentions',
                method: 'POST',
                body: body,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Content-Type': 'application/json',
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /**
     * Analyze retention policy.
     *
     * Analyze a retention policy, and get a list of what would be deleted by it.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.namespace - The namespace to which the retention policy is attached.
     * @param {number} [params.imagesPerRepo] - Determines how many images will be retained for each repository when the
     * retention policy is executed. The value -1 denotes 'Unlimited' (all images are retained).
     * @param {boolean} [params.retainUntagged] - Determines if untagged images are retained when executing the retention
     * policy. This is false by default meaning untagged images will be deleted when the policy is executed.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.JsonObject>>}
     */
    ContainerRegistryV1.prototype.analyzeRetentionPolicy = function (params) {
        var _params = Object.assign({}, params);
        var requiredParams = ['namespace'];
        var missingParams = ibm_cloud_sdk_core_1.getMissingParams(_params, requiredParams);
        if (missingParams) {
            return Promise.reject(missingParams);
        }
        var body = {
            'namespace': _params.namespace,
            'images_per_repo': _params.imagesPerRepo,
            'retain_untagged': _params.retainUntagged
        };
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'analyzeRetentionPolicy');
        var parameters = {
            options: {
                url: '/api/v1/retentions/analyze',
                method: 'POST',
                body: body,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Content-Type': 'application/json',
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /**
     * Get retention policy.
     *
     * Get the retention policy for the specified namespace.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.namespace - Gets the retention policy for the specified namespace.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.RetentionPolicy>>}
     */
    ContainerRegistryV1.prototype.getRetentionPolicy = function (params) {
        var _params = Object.assign({}, params);
        var requiredParams = ['namespace'];
        var missingParams = ibm_cloud_sdk_core_1.getMissingParams(_params, requiredParams);
        if (missingParams) {
            return Promise.reject(missingParams);
        }
        var path = {
            'namespace': _params.namespace
        };
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'getRetentionPolicy');
        var parameters = {
            options: {
                url: '/api/v1/retentions/{namespace}',
                method: 'GET',
                path: path,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /*************************
     * settings
     ************************/
    /**
     * Get account settings.
     *
     * Get account settings for the targeted account.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.AccountSettings>>}
     */
    ContainerRegistryV1.prototype.getSettings = function (params) {
        var _params = Object.assign({}, params);
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'getSettings');
        var parameters = {
            options: {
                url: '/api/v1/settings',
                method: 'GET',
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /**
     * Update account settings.
     *
     * Update settings for the targeted account.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {boolean} [params.platformMetrics] - Opt in to IBM Cloud Container Registry publishing platform metrics.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.Empty>>}
     */
    ContainerRegistryV1.prototype.updateSettings = function (params) {
        var _params = Object.assign({}, params);
        var body = {
            'platform_metrics': _params.platformMetrics
        };
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'updateSettings');
        var parameters = {
            options: {
                url: '/api/v1/settings',
                method: 'PATCH',
                body: body,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Content-Type': 'application/json',
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /*************************
     * tags
     ************************/
    /**
     * Delete tag.
     *
     * Untag a container image in the registry.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.image - The name of the image that you want to delete, in the format
     * &lt;REPOSITORY&gt;:&lt;TAG&gt;.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.ImageDeleteResult>>}
     */
    ContainerRegistryV1.prototype.deleteImageTag = function (params) {
        var _params = Object.assign({}, params);
        var requiredParams = ['image'];
        var missingParams = ibm_cloud_sdk_core_1.getMissingParams(_params, requiredParams);
        if (missingParams) {
            return Promise.reject(missingParams);
        }
        var path = {
            'image': _params.image
        };
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'deleteImageTag');
        var parameters = {
            options: {
                url: '/api/v1/tags/{image}',
                method: 'DELETE',
                path: path,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /*************************
     * trash
     ************************/
    /**
     * List deleted images.
     *
     * List all images that are in the trash can.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {string} [params.namespace] - Limit results to trash can images in the given namespace only.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.JsonObject>>}
     */
    ContainerRegistryV1.prototype.listDeletedImages = function (params) {
        var _params = Object.assign({}, params);
        var query = {
            'namespace': _params.namespace
        };
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'listDeletedImages');
        var parameters = {
            options: {
                url: '/api/v1/trash',
                method: 'GET',
                qs: query,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /**
     * Restore a digest and all associated tags.
     *
     * In the targeted region, restore a digest, and all of its tags in the same repository, from the trash.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.digest - The full IBM Cloud registry digest reference for the digest that you want to
     * restore such as `icr.io/namespace/repo@sha256:a9be...`. Call the `GET /trash/json` endpoint to review digests that
     * are in the trash and their tags in the same repository.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.RestoreResult>>}
     */
    ContainerRegistryV1.prototype.restoreTags = function (params) {
        var _params = Object.assign({}, params);
        var requiredParams = ['digest'];
        var missingParams = ibm_cloud_sdk_core_1.getMissingParams(_params, requiredParams);
        if (missingParams) {
            return Promise.reject(missingParams);
        }
        var path = {
            'digest': _params.digest
        };
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'restoreTags');
        var parameters = {
            options: {
                url: '/api/v1/trash/{digest}/restoretags',
                method: 'POST',
                path: path,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /**
     * Restore deleted image.
     *
     * Restore an image from the trash can.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.image - The name of the image that you want to restore, in the format
     * &lt;REPOSITORY&gt;:&lt;TAG&gt;. Run `ibmcloud cr trash-list` or call the `GET /trash/json` endpoint to review
     * images that are in the trash.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<ContainerRegistryV1.Response<ContainerRegistryV1.Empty>>}
     */
    ContainerRegistryV1.prototype.restoreImage = function (params) {
        var _params = Object.assign({}, params);
        var requiredParams = ['image'];
        var missingParams = ibm_cloud_sdk_core_1.getMissingParams(_params, requiredParams);
        if (missingParams) {
            return Promise.reject(missingParams);
        }
        var path = {
            'image': _params.image
        };
        var sdkHeaders = common_1.getSdkHeaders(ContainerRegistryV1.DEFAULT_SERVICE_NAME, 'v1', 'restoreImage');
        var parameters = {
            options: {
                url: '/api/v1/trash/{image}/restore',
                method: 'POST',
                path: path,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Account': this.account
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    ContainerRegistryV1.DEFAULT_SERVICE_URL = 'https://us.icr.io';
    ContainerRegistryV1.DEFAULT_SERVICE_NAME = 'container_registry';
    return ContainerRegistryV1;
}(ibm_cloud_sdk_core_1.BaseService));
module.exports = ContainerRegistryV1;
//# sourceMappingURL=v1.js.map